@@ -22,18 +22,24 @@
 # Version     : 0.6.1
 # Description : Simple RSS Reader
 # ============================================================================
+#try:
+#    import gtk
+#    import hildon
+#    from gobject import idle_add
+#except:
+#    pass
 
-import gtk
-import hildon
 from ConfigParser import RawConfigParser
-from gobject import idle_add
 from gconf import client_get_default
 from urllib2 import ProxyHandler
+from mainthread import mainthread
+import logging
+logger = logging.getLogger(__name__)
 
 VERSION = "52"
 
 section = "FeedingIt"
-ranges = { "updateInterval":[0.5, 1, 2, 4, 12, 24], "expiry":[24, 48, 72], "fontSize":range(12,24), "orientation":["Automatic", "Landscape", "Portrait"], "artFontSize":[10, 12, 14, 16, 18, 20], "feedsort":["Manual", "Most unread", "Least unread", "Most recent", "Least recent"] }
+ranges = { "updateInterval":[0.5, 1, 2, 4, 12, 24], "expiry":[24, 48, 72, 144, 288], "fontSize":range(12,24), "orientation":["Automatic", "Landscape", "Portrait"], "artFontSize":[10, 12, 14, 16, 18, 20], "feedsort":["Manual", "Most unread", "Least unread", "Most recent", "Least recent"] }
 titles = {"updateInterval":"Auto-update interval", "expiry":"Delete articles", "fontSize":"List font size", "orientation":"Display orientation", "artFontSize":"Article font size","feedsort":"Feed sort order"}
 subtitles = {"updateInterval":"Every %s hours", "expiry":"After %s hours", "fontSize":"%s pixels", "orientation":"%s", "artFontSize":"%s pixels", "feedsort":"%s"}
 
@@ -53,7 +59,9 @@ class Config():
         self.window.destroy()
 
     def createDialog(self):
-        
+        import gtk
+        import hildon
+        from gobject import idle_add
         self.window = gtk.Dialog("Settings", self.parent)
         self.window.set_geometry_hints(min_height=600)
 
@@ -154,7 +162,7 @@ class Config():
         # When the dialog is closed without hitting
         # the "Save" button, restore the configuration
         if self.do_restore_backup:
-            print 'Restoring configuration'
+            logger.debug('Restoring configuration')
             self.config = self.config_backup
 
         self.saveConfig()
@@ -170,6 +178,7 @@ class Config():
         self.saveConfig()
         
     def selection_changed(self, selector, button, setting):
+        from gobject import idle_add
         current_selection = selector.get_current_text()
         if current_selection:
             self.config[setting] = current_selection
@@ -240,6 +249,9 @@ class Config():
         file.close()
 
     def create_selector(self, choices, setting):
+        import gtk
+        import hildon
+        from gobject import idle_add
         #self.pickerDialog = hildon.PickerDialog(self.parent)
         selector = hildon.TouchSelector(text=True)
         index = 0
@@ -271,6 +283,7 @@ class Config():
         return ranges["orientation"].index(self.config["orientation"])
     def getImageCache(self):
         return self.config["imageCache"]
+    @mainthread
     def getProxy(self):
         if self.config["proxy"] == False:
             return (False, None)
